@@ -1,10 +1,12 @@
 """Exceptions used in pyramid_openapi3."""
 
 from openapi_core.schema.exceptions import OpenAPIError
+from openapi_core.unmarshalling.schemas.exceptions import InvalidSchemaFormatValue
 from pyramid.httpexceptions import HTTPBadRequest
 from pyramid.httpexceptions import HTTPInternalServerError
 from pyramid.request import Request
 
+import attr
 import typing as t
 
 
@@ -36,6 +38,17 @@ class ResponseValidationError(HTTPInternalServerError):
         return str(self.detail) if self.detail else self.explanation
 
 
+@attr.s(hash=True)
+class InvalidCustomFormatterValue(InvalidSchemaFormatValue):
+    """Value failed to format with a custom formatter."""
+
+    field = attr.ib()
+
+    def __str__(self) -> str:
+        """Provide more control over error message."""
+        return str(self.original_exception)
+
+
 def extract_errors(
     request: Request, errors: t.List[OpenAPIError]
 ) -> t.Iterator[t.Dict[str, str]]:
@@ -94,22 +107,18 @@ def extract_errors(
         output.update({"message": message})
 
         field = None
-        if getattr(err, "name", None) is not None:
+        if getattr(err, "field", None) is not None:
+            field = err.field
+        elif getattr(err, "name", None) is not None:
             field = err.name
         elif (
             getattr(err, "validator", None) is not None and err.validator == "required"
         ):
             field = "/".join(err.validator_value)
-        elif getattr(err, "validator", None) is not None and err.validator == "format":
-            field = None  # TODO: figure out how to get field name here
-        elif getattr(err, "validator", None) is not None and err.validator == "pattern":
-            field = None  # TODO: figure out how to get field name here
         elif (
             getattr(err, "path", None) and err.path[0] and isinstance(err.path[0], str)
         ):
             field = "/".join(err.path)
-        elif getattr(err, "relative_schema_path", None):
-            field = "/".join(err.relative_schema_path)
 
         if field:
             output.update({"field": field})
